module.exports = {
	extends: [
		'@nextcloud'
	]
}
